<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>KWin::MultitaskViewEffect</name>
    <message>
        <source>Drag upwards to remove</source>
        <translation>Arrossegueu-ho amunt per eliminar-ho.</translation>
    </message>
    <message>
        <source>No windows</source>
        <translation>Sense finestres</translation>
    </message>
</context>
</TS>